Permission-manager
==================

Permission-manager is an application for managing permissions in python.


.. toctree::
    :maxdepth: 2
    :caption: User Guide

    source/install
    source/usage
    source/managers
    source/async
    source/result
    source/utils
